*Make three-country dataset analysis-ready
*Configured
if "${gsdData}"=="" {
	di as error "Configure work environment by running init.do before running the code."
	error 1
}

set more off
use "${gsdData}/1-CleanInput/hh.dta", clear

*Generate variable with emergency and non-emergency status of all regions
gen emergency = inlist(country, 2,3) if !missing(country)
replace emergency = 1 if inlist(strata, 401, 403)
label variable emergency "Emergency area (as per IPC)"
label define lemergency 1 "Emergency" 0 "Non-Emergency"
label values emergency lemergency
tab emergency strata
order emergency, after(s_v)

*Consolidate household head's gender
replace hhh_gender = gender if hhh_relation ==1 & missing(hhh_gender)
replace hhh_gender = 1 - gender if hhh_relation ==2 & missing(hhh_gender)
tab hhh_gender hhh_relation if hhh_relation <3
assert hhh_gender == gender if hhh_relation ==1

*Consolidate years living in current residence
gen residence_years = current_residence_years if current_residence == 1
replace residence_years = current_residence_months/12 if current_residence == 2
order residence_years, before(current_residence)

*Calculate Coping Strategy Index as per WFP manual
foreach var of varlist vm_02* {
	*Turning "household never does this" to 0
	replace `var'=0 if `var'<0 
}
gen csi=((vm_02a*1) + (vm_02b*2) + (vm_02c*1) + (vm_02d*3) + (vm_02e*1))
label variable csi "Coping Strategy Index (CSI Score)"
gen csi_cat=.
replace csi_cat=1 if csi<=3
replace csi_cat=2 if csi>3 & csi<=9 
replace csi_cat=3 if csi>=10 & !missing(csi)
assert csi_cat==. if csi==.
label define lcsicategories 1 "No or low" 2 "Medium" 3 "High"
label val csi_cat lcsicategories
label variable csi_cat "Coping Strategy Index (CSI) Score: Categorized"
*Get inverted csi score for intuitive graphing
sum csi
gen csi_invert = 56-csi
sum csi_invert
label variable csi_invert "Food Security Score (invert of CSI)"

*Generate categories for source of water
gen watersource = 1 if inlist(wa_01, 1,2,3,4,6,7 ) & !missing(wa_01)
replace watersource = 0 if inlist(wa_01, 5,8,9) & !missing(wa_01)
replace watersource = . if wa_01 == 1000
label variable watersource "Water source: Categorized (as per WASH Indicator manual)"
label define lwatersourcecat 0 "Unimproved" 1 "Improved" 
label values watersource lwatersourcecat
order watersource, after(wa_01)

*Consolidate duration variables
*Time to market
gen duration_market  = . 
replace duration_market = fm_05_hours if fm_05 ==1
replace duration_market = fm_05_minutes/60 if fm_05 ==2
label var duration_market "Hours to reach nearest market for grains/cereals"
order duration_market, before(fm_05)
*Time to water source
gen duration_water  = . 
replace duration_water = wa_03_hours if wa_03 ==1
replace duration_water = wa_03_minutes/60 if wa_03 ==2
label var duration_water "Hours to reach nearest water source"
order duration_water, before(wa_03)
*Time to health facility
gen duration_health  = . 
replace duration_health = he_08_hours if he_08 ==1
replace duration_health = he_08_minutes/60 if he_08 ==2
label var duration_health "Hours to reach nearest health facility"
order duration_health, before(he_08)

*Outlier correction for numeric variables - convert to median if more than 3 sd's
*Using 3sd as a threshold as histograms show that all the distributions are concentrated around 0-1 hours.
levelsof country, local(country1)
foreach i of local country1 {
	foreach var of varlist duration_market duration_water duration_health {
		*Getting means and sd's country-wise
		sum `var' if country ==`i', d 
		*Tagging outliers
		replace `var' = .o if `var' > (r(mean) + 3*r(sd)) | `var' < (r(mean) - 3*r(sd))
		*Turn outlier values to post-outlier median
		sum `var', d
		replace `var'= r(p50) if `var' == .o
	}
}

*Farming income, wage income, non farming income
gen farm_profits = in_01 == 2 if !missing(in_01)
label variable farm_profits "Main income is farm profits"
gen nonfarm_profits = in_01 ==3 if !missing(in_01)
label variable nonfarm_profits "Main income is non-farm profits"
gen wages = in_01 == 1 if !missing(in_01)
label variable wages "Main income is wages"
order farm_profits nonfarm_profits wages, after(in_01)

*Farming employment, non-farming employment, nomads
gen farm_employ = inlist(em_01, 1,2,5) if !missing(em_01)
label variable farm_employ "Main employment is in farming"
gen nonfarm_employ = inlist(em_01, 3,4) if !missing(em_01)
label variable farm_employ "Main employment is in mon-farming"
gen nomad = em_01 ==6 if !missing(em_01)
label variable nomad "Main employment is in nomadic work"
order farm_employ nonfarm_employ nomad, after(em_01)

*Consolidate drought preparedness variable
gen droughtprepared = .
replace droughtprepared = 1 if inlist(wa_12, 3,4)
replace droughtprepared = 0 if inlist(wa_12, 1,2)
label define ldroughtprepared 1 "Prepared" 0 "Unprepared"
label values droughtprepared ldroughtprepared
label variable droughtprepared "Prepared for drought"
order droughtprepared, after(wa_12)

*Consolidate storage variable
gen storefood = . 
replace storefood = 1 if fm_11 < 6
replace storefood = 0 if fm_11 == 6
label define lstorefood 0 "Don't store food" 1 "Store food"
label values storefood lstorefood
label variable storefood "Household stores food for future use"
order storefood, after(fm_11)

*Drop unnecessary multiselect variables
drop in_10__n98 in_10__n99
drop he_02__n98 he_02__n99
*Generate sum of multiselect options
egen in_10_n=rowtotal(in_10__*)
label variable in_10_n "Number of remittance options known to household"
order in_10_n, after(in_10__10)
egen he_02_n=rowtotal(he_02__*)
label variable he_02_n "Number of diseases occuring in household in last 3 months"
order he_02_n, after(he_02__7)

saveold "${gsdData}/1-CleanOutput/hh.dta", replace version(11)
export delimited using "${gsdData}/1-CleanOutput/hh.csv", replace

*ASSETS DATASET
use "${gsdData}/1-CleanInput/assets.dta", clear
*Lost assets
gen asset_decrease = as_02 ==2 & !missing(as_02)
label variable asset_decrease "Decrease in assets"
*Sold assets 
gen asset_sold = as_03 == 1 & !missing(as_03)
label variable asset_sold "Sold assets"
*Reason for decrease
tab as_03
gen reasondecrease = as_03
replace reasondecrease = 777 if as_03 == .z & !missing(as_02)
label define lassetdecrease 777 "No decrease" 1000 "Other" , modify
label values reasondecrease lassetdecrease
order reasondecrease, after(as_03)
*Merge in asset possessoin, csi scores, income and employment sources from main dataset
merge m:1 hhid using "${gsdData}/1-CleanOutput/hh.dta", nogen keepusing(as_01* csi csi_cat in_01 in_02 in_03 em_01 em_02 em_03)
*Order and sort
order country hhid strata weight numassets asset_id as_01* as_02 as_03*
order hhid *version, last
sort country hhid 
saveold "${gsdData}/1-CleanOutput/assets.dta", replace version(11)
export delimited using "${gsdData}/1-CleanOutput/assets.csv", replace
